@@ -30,13 +30,13 @@ parser.add_argument('--image', help='Generate Image (JPEG/PNG) file', action='st
 args = parser.parse_args()
 
 if not args.key.exists():
-    out.write(str(args.key) + ' Does not exists')
+    out.write('Key file: ' + str(args.key) + ' Does not exists \n')
     exit(1)
 if not args.output.exists():
-    out.write(str(args.output) + ' Does not exists')
+    out.write('Output folder: ' + str(args.output) + ' Does not exists \n')
     exit(1)
 if not args.resources.exists():
-    out.write(str(args.resources) + ' Does not exists')
+    out.write('Resources folder: ' + str(args.resources) + ' Does not exists \n')
     exit(1)
 
 renderer = pystache.Renderer();
@@ -143,6 +143,7 @@ def main():
         html_generated = False;
 
         tname = hash['template'];
+        hash['TEMPLATE_PATH'] = args.resources.resolve()
         parsed = None;
         if tname in templates:
             parsed = templates[tname];
@@ -177,12 +178,12 @@ def main():
             html_content = render(parsed, hash, htmlfile, save_as_file=True);
             wks.update_cell(i+1, html_done_status+1,  htmlfile);
             html_generated = True;
-            print(htmlfile)
+            print(htmlfile + ' \n')
 
         if (hash.get('pdf_done_status', '') == ''):
             pdffile = '-'
             if args.pdf:
-                out.write('Generating the PDF for html: ' + htmlfile);
+                out.write('Generating the PDF for html: ' + htmlfile + '\n');
 
                 pdffile = createDirs(baseFolder + "/pdf/", filename + ".pdf");
 
@@ -215,7 +216,7 @@ def main():
         if (hash.get('jpg_done_status', '') == ''):
             jpgfile = '-'
             if args.image:
-                out.write('Generating the jpg for html: ' + htmlfile);
+                out.write('Generating the jpg for html: ' + htmlfile + ' \n');
 
                 jpgfile = createDirs(baseFolder + "/jpg/", filename + ".jpg");
                 imgkit.from_string(
